package ruddygreat.diableavionics.hullmods;

package ..deTemp.1737093384470;

import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.combat.BaseHullMod;
import com.fs.starfarer.api.combat.FighterLaunchBayAPI;
import com.fs.starfarer.api.combat.MutableShipStatsAPI;
import com.fs.starfarer.api.combat.ShipAPI;
import com.fs.starfarer.api.combat.ShipVariantAPI;
import com.fs.starfarer.api.loading.FighterWingSpecAPI;
import com.fs.starfarer.api.ui.Alignment;
import com.fs.starfarer.api.ui.TooltipMakerAPI;
import java.awt.Color;
import java.util.ArrayList;
import java.util.List;
import ruddygreat.diableavionics.scripts.util.Diableavionics_stringsManager;

public class DiableAvionicsUniversalDecksUpgrade2 extends BaseHullMod {
  public String getDescriptionParam(int index, ShipAPI.HullSize hullSize) {
    if (index == 0)
      return Diableavionics_stringsManager.txt("hm_gantry_101"); 
    return null;
  }
  
  private final Color HL = Global.getSettings().getColor("hColor");
  
  public void addPostDescriptionSection(TooltipMakerAPI tooltip, ShipAPI.HullSize hullSize, ShipAPI ship, float width, boolean isForModSpec) {
    tooltip.addSectionHeading(Diableavionics_stringsManager.txt("hm_gantry_102"), Alignment.MID, 15.0F);
    if (ship != null && ship.getVariant() != null)
      if (ship.getVariant().getFittedWings().isEmpty()) {
        tooltip.addPara(
            Diableavionics_stringsManager.txt("hm_gantry_103"), 10.0F, this.HL, new String[0]);
      } else if (noWanzer(ship.getVariant())) {
        tooltip.addPara(
            Diableavionics_stringsManager.txt("hm_gantry_104"), 10.0F, this.HL, new String[0]);
      } else {
        List<String> wanzers = allWanzers(ship.getVariant());
        if (!wanzers.isEmpty()) {
          tooltip.addPara(
              Diableavionics_stringsManager.txt("hm_gantry_105"), 10.0F, this.HL, new String[] { Diableavionics_stringsManager.txt("hm_gantry_105hl") });
          tooltip.setBulletedListMode("    - ");
          for (String w : wanzers)
            tooltip.addPara(w, 3.0F); 
          tooltip.setBulletedListMode(null);
        } 
      }  
  }
  
  private final String ID = "wanzer_gantry", TAG = "wanzer";
  
  public void advanceInCombat(ShipAPI ship, float amount) {
    if (ship.getOriginalOwner() == -1)
      return; 
    boolean allDeployed = true, ranOnce = false;
    for (FighterLaunchBayAPI bay : ship.getLaunchBaysCopy()) {
      if (bay.getWing() != null) {
        ranOnce = true;
        if (bay.getWing().getSpec().hasTag("wanzer")) {
          FighterWingSpecAPI wingSpec = bay.getWing().getSpec();
          int deployed = bay.getWing().getWingMembers().size();
          int maxTotal = wingSpec.getNumFighters() + 1;
          int actualAdd = maxTotal - deployed;
          if (actualAdd > 0) {
            bay.setExtraDeployments(actualAdd);
            bay.setExtraDeploymentLimit(maxTotal);
            bay.setExtraDuration(9999999.0F);
            allDeployed = false;
          } else {
            bay.setExtraDeployments(0);
            bay.setExtraDeploymentLimit(0);
            bay.setFastReplacements(0);
          } 
          if (ship.getMutableStats().getFighterRefitTimeMult().getPercentStatMod("wanzer_gantry") == null && actualAdd != 0)
            bay.setFastReplacements(actualAdd); 
        } 
      } 
    } 
    if (ship.getMutableStats().getFighterRefitTimeMult().getPercentStatMod("wanzer_gantry") == null && allDeployed && ranOnce)
      ship.getMutableStats().getFighterRefitTimeMult().modifyPercent("wanzer_gantry", 1.0F); 
  }
  
  public void applyEffectsBeforeShipCreation(ShipAPI.HullSize hullSize, MutableShipStatsAPI stats, String id) {
    stats.getFighterRefitTimeMult().unmodify("wanzer_gantry");
  }
  
  public void applyEffectsAfterShipCreation(ShipAPI ship, String id) {
    Integer crafts = Integer.valueOf(0), extraCrafts = Integer.valueOf(0);
    for (String w : ship.getVariant().getFittedWings()) {
      if (Global.getSettings().getFighterWingSpec(w).hasTag("wanzer")) {
        crafts = Integer.valueOf(crafts.intValue() + Global.getSettings().getFighterWingSpec(w).getNumFighters());
        Integer integer1 = extraCrafts, integer2 = extraCrafts = Integer.valueOf(extraCrafts.intValue() + 1);
      } 
    } 
    if (extraCrafts.intValue() > 0)
      ship.getMutableStats().getDynamic().getMod("replacement_rate_decrease_mult").modifyMult(id, ((crafts.intValue() + extraCrafts.intValue()) / crafts.intValue())); 
  }
  
  public boolean isApplicableToShip(ShipAPI ship) {
    if (ship == null)
      return false; 
    return (ship.getMutableStats().getNumFighterBays().getModifiedValue() > 0.0F && !ship.getVariant().getHullMods().contains("diableavionics_universaldecksBI"));
  }
  
  public String getUnapplicableReason(ShipAPI ship) {
    if (ship.getVariant().getHullMods().contains("diableavionics_universaldecksBI"))
      return Diableavionics_stringsManager.txt("hm_builtin"); 
    return Diableavionics_stringsManager.txt("hm_noBays");
  }
  
  private boolean noWanzer(ShipVariantAPI variant) {
    boolean noWanzer = true;
    for (String w : variant.getFittedWings()) {
      if (Global.getSettings().getFighterWingSpec(w).hasTag("wanzer")) {
        noWanzer = false;
        break;
      } 
    } 
    return noWanzer;
  }
  
  private List<String> allWanzers(ShipVariantAPI variant) {
    List<String> allWanzers = new ArrayList<>();
    for (String w : variant.getFittedWings()) {
      FighterWingSpecAPI f = Global.getSettings().getFighterWingSpec(w);
      if (f.hasTag("wanzer"))
        allWanzers.add(f.getWingName() + " " + f.getRoleDesc()); 
    } 
    return allWanzers;
  }
}
